==> lasta-di-0.6.1-sources.jar: org/lastaflute/di/core/deployer/RequestComponentDeployer.java <==
/*
 * Copyright 2014-2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.lastaflute.di.core.deployer;

import java.util.Map;

import org.lastaflute.di.core.ComponentDef;
import org.lastaflute.di.core.ExternalContext;
import org.lastaflute.di.exception.EmptyRuntimeException;
import org.lastaflute.di.helper.log.SLogger;

/**
 * @author modified by jflute (originated in Seasar)
 * 
 */
public class RequestComponentDeployer extends AbstractComponentDeployer {

    private static SLogger logger = SLogger.getLogger(RequestComponentDeployer.class);

    /**
     * @param componentDef
     */
    public RequestComponentDeployer(ComponentDef componentDef) {
        super(componentDef);
    }

    /**
     * @see org.lastaflute.di.core.deployer.ComponentDeployer#deploy()
     */
    public Object deploy() {
        ComponentDef cd = getComponentDef();
        ExternalContext extCtx = cd.getContainer().getRoot().getExternalContext();
        if (extCtx == null) {
            RuntimeException re = new EmptyRuntimeException("externalContext");
            logger.log(re);
            throw re;
        }
        Map requestMap = extCtx.getRequestMap();
        String componentName = getComponentName();
        Object component = null;
        component = requestMap.get(componentName);
        if (component != null) {
            return component;
        }
        component = getConstructorAssembler().assemble();
        requestMap.put(componentName, component);
        getPropertyAssembler().assemble(component);
        getInitMethodAssembler().assemble(component);
        return component;
    }

    public void injectDependency(Object component) {
        throw new UnsupportedOperationException("injectDependency");
    }

    /**
     * @see org.lastaflute.di.core.deployer.ComponentDeployer#init()
     */
    public void init() {
    }

    /**
     * @see org.lastaflute.di.core.deployer.ComponentDeployer#destroy()
     */
    public void destroy() {
    }
}

==> lasta-di-0.7.6-sources.jar: org/lastaflute/di/core/deployer/RequestComponentDeployer.java <==
/*
 * Copyright 2015-2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.lastaflute.di.core.deployer;

import java.util.Map;

import org.lastaflute.di.core.ComponentDef;
import org.lastaflute.di.core.ExternalContext;
import org.lastaflute.di.exception.EmptyRuntimeException;
import org.lastaflute.di.helper.log.LaLogger;

/**
 * @author modified by jflute (originated in Seasar)
 * 
 */
public class RequestComponentDeployer extends AbstractComponentDeployer {

    private static LaLogger logger = LaLogger.getLogger(RequestComponentDeployer.class);

    public RequestComponentDeployer(ComponentDef componentDef) {
        super(componentDef);
    }

    public Object deploy() {
        ComponentDef cd = getComponentDef();
        ExternalContext extCtx = cd.getContainer().getRoot().getExternalContext();
        if (extCtx == null) {
            RuntimeException re = new EmptyRuntimeException("externalContext");
            logger.log(re);
            throw re;
        }
        Map<String, Object> requestMap = extCtx.getRequestMap();
        String componentName = getComponentName();
        Object component = null;
        component = requestMap.get(componentName);
        if (component != null) {
            return component;
        }
        component = getConstructorAssembler().assemble();
        requestMap.put(componentName, component);
        getPropertyAssembler().assemble(component);
        getInitMethodAssembler().assemble(component);
        return component;
    }

    public void injectDependency(Object component) {
        throw new UnsupportedOperationException("injectDependency");
    }

    public void init() {
    }

    public void destroy() {
    }
}
